'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _bind = require('classnames/bind');

var _bind2 = _interopRequireDefault(_bind);

require('terra-base/lib/baseStyles');

var _Select = require('./Select.scss');

var _Select2 = _interopRequireDefault(_Select);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var cx = _bind2.default.bind(_Select2.default);

var propTypes = {

  /**
   * WARNING: This prop is deprecated, please use the options prop.
   * List of choices to be selected.
   * If choices and options array are supplied, options array will be used over choices.
   */
  choices: _propTypes2.default.array,

  /**
   * List of object key and value pairs for choices to be selected.
   * If choices and options array are supplied, options array will be used over choices.
   */
  options: _propTypes2.default.arrayOf(_propTypes2.default.shape({
    value: _propTypes2.default.string.isRequired,
    display: _propTypes2.default.string.isRequired,
    disabled: _propTypes2.default.bool
  })),

  /**
   * Function to trigger when the user changes the select value. Provide a function to create a controlled input.
   */
  onChange: _propTypes2.default.func,

  /**
   * Name of the select field.
   */
  name: _propTypes2.default.string,

  /**
   * Whether the select is required or not.
   */
  required: _propTypes2.default.bool,

  /**
   * The value to start the select on.
   */
  defaultValue: _propTypes2.default.string,

  /**
   * The value of the select element. Use this to create a controlled input.
   */
  value: _propTypes2.default.string
};

var defaultProps = {
  choices: null,
  options: null,
  onChange: undefined,
  name: null,
  required: false,
  defaultValue: undefined,
  value: undefined
};

var Select = function Select(_ref) {
  var choices = _ref.choices,
      options = _ref.options,
      onChange = _ref.onChange,
      name = _ref.name,
      required = _ref.required,
      defaultValue = _ref.defaultValue,
      value = _ref.value,
      customProps = _objectWithoutProperties(_ref, ['choices', 'options', 'onChange', 'name', 'required', 'defaultValue', 'value']);

  var additionalSelectProps = _extends({}, customProps);
  var selectClasses = cx(['select', additionalSelectProps.className]);

  if (required) {
    additionalSelectProps['aria-required'] = 'true';
  }

  var finalOptions = void 0;
  if (choices && options === null) {
    // Build out key & value array for deprecated choices prop
    finalOptions = choices.map(function (choice) {
      return { value: choice, display: choice };
    });
    /* eslint-disable no-console */
    console.warn('The choices prop for the Terra Form Select component is deprecated and will be removed in a later release. Please use the options prop instead https://terra-ui.herokuapp.com/components/core/form#select.');
    /* eslint-disable no-console */
  } else {
    finalOptions = options;
  }

  return _react2.default.createElement(
    'select',
    _extends({}, additionalSelectProps, {
      name: name,
      required: required,
      onChange: onChange,
      defaultValue: defaultValue,
      value: value,
      className: selectClasses
    }),
    finalOptions.map(function (option) {
      return _react2.default.createElement(
        'option',
        { key: option.value + '-' + option.display, value: option.value, disabled: option.disabled },
        option.display
      );
    })
  );
};

Select.propTypes = propTypes;
Select.defaultProps = defaultProps;

exports.default = Select;